//+-------------------------------------------------------------------+
//|                                                  RiskRewardFib.mq4|
//|                                                  By Wolverine     |
//+-------------------------------------------------------------------+

string RRLevels   = "2,3,4,6,8,10";  //add levels if needed 
color  FibColor   = Blue;           //change to what you find nice 
string UniqueId   = "RiskReward_Fib_";

//+------------------------------------------------------------------+
int start(){
//+------------------------------------------------------------------+
  Comment ("");
  if (ObjectFind(UniqueId) != -1) 
   {del_obj();}else{RRFib();} 
}


//+------------------------------------------------------------------+
void del_obj()  {
//+------------------------------------------------------------------+
  int k=0;
  while (k<ObjectsTotal())   {
    string objname = ObjectName(k);
    if (StringSubstr(objname,0,StringLen(UniqueId)) == UniqueId)  
      ObjectDelete(objname);
    else
      k++;
  }    
  return(0);
}

//+------------------------------------------------------------------+
void RRFib()  {
//+------------------------------------------------------------------+
   string fibname = UniqueId;
   double TIME = iTime(NULL,0,0);
   double TIME1 = iTime(NULL,0,3);
   double Fib0Level = High[1];
   double Fib1Level = Low[1];
   
   int RRlevelsCount = StringFindCount(RRLevels, ",")+1;
   double RR_array[20];
   StrToDoubleArray(RRLevels,RR_array);
   ArrayResize(RR_array,RRlevelsCount); 
   
   drawFibo(fibname,TIME1,Fib0Level,TIME,Fib1Level,1,1,RRlevelsCount+2,FibColor,FibColor);
   ObjectSet(fibname, OBJPROP_FIRSTLEVEL+0, 0.0);
   ObjectSetFiboDescription(fibname,0,"Stop   @%$");
   ObjectSet(fibname, OBJPROP_FIRSTLEVEL+1, 1.0);
   ObjectSetFiboDescription(fibname,1,"Entry  @%$");
   
   for(int j=0; j<=RRlevelsCount; j++){
      int x = j+2;
      ObjectSet(fibname, OBJPROP_FIRSTLEVEL+x, RR_array[j]+1);
      string temp = DoubleToStr(RR_array[j],0);
      ObjectSetFiboDescription(fibname,x,temp + ":1  @%$");
      }
}


//+---------------------------------------------------------------------------------------------------------------------------+
void drawFibo(string n, datetime t1, double p1, datetime t2, double p2, int st, int w, int l, color lc, color c = CLR_NONE){
//+---------------------------------------------------------------------------------------------------------------------------+
   ObjectDelete(n);
   ObjectCreate(n, OBJ_FIBO, 0,t1,p1,t2,p2);
   ObjectSet(n, OBJPROP_COLOR, c);
   ObjectSet(n, OBJPROP_STYLE, st);
   ObjectSet(n, OBJPROP_WIDTH, w);
   ObjectSet(n, OBJPROP_RAY, false);
   ObjectSet(n, OBJPROP_BACK, true);   
   ObjectSet(n, OBJPROP_FIBOLEVELS, l);
   ObjectSet(n, OBJPROP_LEVELCOLOR, lc);
   return(0);
}


//+------------------------------------------------------------------+
int StrToDoubleArray(string str, double &a[], string delim=",", int init=0)  {
//+------------------------------------------------------------------+
// Breaks down a single string into double array 'a' (elements delimited by 'delim')
//  e.g. string is "1,2,3,4,5";  if delim is "," then the result will be
//  a[0]=1.0   a[1]=2.0   a[2]=3.0   a[3]=4.0   a[4]=5.0
//  Unused array elements are initialized by value in 'init' (default is 0)
  for (int i=0; i<ArraySize(a); i++)
    a[i] = init;
  if (str == "")  return(0);  
  int z1=-1, z2=0;
  if (StringRight(str,1) != delim)  str = str + delim;
  for (i=0; i<ArraySize(a); i++)  {
    z2 = StringFind(str,delim,z1+1);
    if (z2>z1+1)  a[i] = StrToNumber(StringSubstr(str,z1+1,z2-z1-1));
    if (z2 >= StringLen(str)-1)   break;
    z1 = z2;
  }
  return(StringFindCount(str,delim));
}

//+------------------------------------------------------------------+
int StringFindCount(string str, string str2)
//+------------------------------------------------------------------+
// Returns the number of occurrences of STR2 in STR
// Usage:   int x = StringFindCount("ABCDEFGHIJKABACABB","AB")   returns x = 3
{
  int c = 0;
  for (int i=0; i<StringLen(str); i++)
    if (StringSubstr(str,i,StringLen(str2)) == str2)  c++;
  return(c);
}

//+------------------------------------------------------------------+
string StringRight(string str, int n=1)
//+------------------------------------------------------------------+
// Returns the rightmost N characters of STR, if N is positive
// Usage:    string x=StringRight("ABCDEFG",2)  returns x = "FG"
//
// Returns all but the leftmost N characters of STR, if N is negative
// Usage:    string x=StringRight("ABCDEFG",-2)  returns x = "CDEFG"
{
  if (n > 0)  return(StringSubstr(str,StringLen(str)-n,n));
  if (n < 0)  return(StringSubstr(str,-n,StringLen(str)-n));
  return("");
}

//+------------------------------------------------------------------+
double StrToNumber(string str)  {
//+------------------------------------------------------------------+
// Usage: strips all non-numeric characters out of a string, to return a numeric (double) value
//  valid numeric characters are digits 0,1,2,3,4,5,6,7,8,9, decimal point (.) and minus sign (-)
// Example: StrToNumber("the balance is $-34,567.98") returns the numeric value -34567.98
  int    dp   = -1;
  int    sgn  = 1;
  double num  = 0.0;
  for (int i=0; i<StringLen(str); i++)  {
    string s = StringSubstr(str,i,1);
    if (s == "-")  sgn = -sgn;   else
    if (s == ".")  dp = 0;       else
    if (s >= "0" && s <= "9")  {
      if (dp >= 0)  dp++;
      if (dp > 0)
        num = num + StrToInteger(s) / MathPow(10,dp);
      else
        num = num * 10 + StrToInteger(s);
    }
  }
  return(num*sgn);
}